@@ -79,6 +79,13 @@ enum TapButtonState {
     TBS_BUTTON_DOWN_UP		/* Send button down event + set up state */
 };
 
+enum TouchpadModel {
+    MODEL_UNKNOWN = 0,
+    MODEL_SYNAPTICS,
+    MODEL_ALPS,
+    MODEL_APPLETOUCH
+};
+
 typedef struct _SynapticsPrivateRec
 {
     SynapticsSHM synpara_default;	/* Default parameter settings, read from
@@ -95,7 +102,6 @@ typedef struct _SynapticsPrivateRec
     OsTimerPtr timer;			/* for up/down-button repeat, tap processing, etc */
 
     struct CommData comm;
-    int fifofd;		 		/* fd for fifo */
 
     SynapticsMoveHistRec move_hist[SYNAPTICS_MOVE_HISTORY]; /* movement history */
     int hist_index;			/* Last added entry in move_hist[] */
@@ -140,6 +146,15 @@ typedef struct _SynapticsPrivateRec
     int avg_width;			/* weighted average of previous fingerWidth values */
 
     int minx, maxx, miny, maxy;         /* min/max dimensions as detected */
+    int minp, maxp, minw, maxw;		/* min/max pressure and finger width as detected */
+    Bool has_left;			/* left button detected for this device */
+    Bool has_right;			/* right button detected for this device */
+    Bool has_middle;			/* middle button detected for this device */
+    Bool has_double;			/* double click detected for this device */
+    Bool has_triple;			/* triple click detected for this device */
+    Bool has_pressure;			/* device reports pressure */
+
+    enum TouchpadModel model;          /* The detected model */
 } SynapticsPrivate;
 
 #endif /* _SYNAPTICSSTR_H_ */
